@@ -186,7 +186,8 @@ class PyMvnGit:
         currentDirectory = os.getcwd()
         #For testing/development
         #currentDirectory  = "/home/ualter/Developer/teachstore"
-        currentDirectory = "d:\\Developer\\code\\teachstore"
+        #currentDirectory = "d:\\Developer\\code\\teachstore"
+        #currentDirectory  = "/home/ualter/Developer"
         return currentDirectory
 
     def _encodeDirectoryName(self, directory):
@@ -204,7 +205,7 @@ class PyMvnGit:
         \033[0;0m   
         """
         if not self._connectedDatabase:
-           self._connectDBs()
+           self._databaseMacro = TinyDB(self._fileDBMacro, indent=4)
 
         records = self._databaseMacro.all()
         if jsonFormat:
@@ -258,6 +259,8 @@ class PyMvnGit:
                   prettyTable.ascendingOrder(True)
                   Console.printTable2("MACRO: {igreen}{key}{green} - {cyan}{desc}{reset}". \
                       format(key=r["key"],desc=r["description"],igreen=Colors.IGREEN,green=Colors.GREEN,cyan=Colors.CYAN,reset=Colors.RESET), prettyTable, tableArgs)             
+
+        self._databaseMacro.close()
    
     def listProjects(self, jsonFormat=False):
         """
